@@ -47,7 +47,7 @@ namespace QtWaylandServer {
             ivi_surface *ivi_surface_object;
             struct ::wl_resource *handle;
 
-            struct ::wl_client *client() const { return handle->client; }
+            struct ::wl_client *client() const { return wl_resource_get_client(handle); }
             int version() const { return wl_resource_get_version(handle); }
 
             static Resource *fromResource(struct ::wl_resource *resource);
@@ -129,7 +129,7 @@ namespace QtWaylandServer {
             ivi_application *ivi_application_object;
             struct ::wl_resource *handle;
 
-            struct ::wl_client *client() const { return handle->client; }
+            struct ::wl_client *client() const { return wl_resource_get_client(handle); }
             int version() const { return wl_resource_get_version(handle); }
 
             static Resource *fromResource(struct ::wl_resource *resource);
